@@ -1,7 +1,7 @@
 """
-Anything related to XMP metadata.
+Anything related to Extensible Metadata Platform (XMP) metadata.
 
-See https://en.wikipedia.org/wiki/Extensible_Metadata_Platform
+https://en.wikipedia.org/wiki/Extensible_Metadata_Platform
 """
 
 import datetime
@@ -16,17 +16,13 @@ from typing import (
     Optional,
     TypeVar,
     Union,
-    cast,
 )
 from xml.dom.minidom import Document, parseString
 from xml.dom.minidom import Element as XmlElement
 from xml.parsers.expat import ExpatError
 
-from ._utils import (
-    StreamType,
-    deprecate_with_replacement,
-    deprecation_with_replacement,
-)
+from ._protocols import XmpInformationProtocol
+from ._utils import StreamType, deprecate_no_replacement
 from .errors import PdfReadError
 from .generic import ContentStream, PdfObject
 
@@ -43,19 +39,22 @@ XMPMM_NAMESPACE = "http://ns.adobe.com/xap/1.0/mm/"
 # documented meaning.
 #
 # Elements in the namespace are key/value-style storage,
-# where the element name is the key and the content is the value.  The keys
+# where the element name is the key and the content is the value. The keys
 # are transformed into valid XML identifiers by substituting an invalid
 # identifier character with \u2182 followed by the unicode hex ID of the
-# original character.  A key like "my car" is therefore "my\u21820020car".
+# original character. A key like "my car" is therefore "my\u21820020car".
 #
 # \u2182 is the unicode character \u{ROMAN NUMERAL TEN THOUSAND}
 #
-# The pdfx namespace should be avoided.  A
-# custom data schema and sensical XML elements could be used instead, as is
+# The pdfx namespace should be avoided.
+# A custom data schema and sensical XML elements could be used instead, as is
 # suggested by Adobe's own documentation on XMP under "Extensibility of
 # Schemas".
 PDFX_NAMESPACE = "http://ns.adobe.com/pdfx/1.3/"
 
+# PDF/A
+PDFAID_NAMESPACE = "http://www.aiim.org/pdfa/ns/id/"
+
 iso8601 = re.compile(
     """
         (?P<year>[0-9]{4})
@@ -110,6 +109,21 @@ def _converter_date(value: str) -> datetime.datetime:
     return dt
 
 
+def _generic_get(
+        element: XmlElement, self: "XmpInformation", list_type: str, converter: Callable[[Any], Any] = _identity
+) -> Optional[List[str]]:
+    containers = element.getElementsByTagNameNS(RDF_NAMESPACE, list_type)
+    retval: List[Any] = []
+    if len(containers):
+        for container in containers:
+            for item in container.getElementsByTagNameNS(RDF_NAMESPACE, "li"):
+                value = self._get_text(item)
+                value = converter(value)
+                retval.append(value)
+        return retval
+    return None
+
+
 def _getter_bag(
     namespace: str, name: str
 ) -> Callable[["XmpInformation"], Optional[List[str]]]:
@@ -117,14 +131,13 @@ def _getter_bag(
         cached = self.cache.get(namespace, {}).get(name)
         if cached:
             return cached
-        retval = []
+        retval: List[str] = []
         for element in self.get_element("", namespace, name):
-            bags = element.getElementsByTagNameNS(RDF_NAMESPACE, "Bag")
-            if len(bags):
-                for bag in bags:
-                    for item in bag.getElementsByTagNameNS(RDF_NAMESPACE, "li"):
-                        value = self._get_text(item)
-                        retval.append(value)
+            if (bags := _generic_get(element, self, list_type="Bag")) is not None:
+                retval.extend(bags)
+            else:
+                value = self._get_text(element)
+                retval.append(value)
         ns_cache = self.cache.setdefault(namespace, {})
         ns_cache[name] = retval
         return retval
@@ -141,13 +154,17 @@ def _getter_seq(
             return cached
         retval = []
         for element in self.get_element("", namespace, name):
-            seqs = element.getElementsByTagNameNS(RDF_NAMESPACE, "Seq")
-            if len(seqs):
-                for seq in seqs:
-                    for item in seq.getElementsByTagNameNS(RDF_NAMESPACE, "li"):
-                        value = self._get_text(item)
-                        value = converter(value)
-                        retval.append(value)
+            if (seqs := _generic_get(element, self, list_type="Seq", converter=converter)) is not None:
+                retval.extend(seqs)
+            elif (bags := _generic_get(element, self, list_type="Bag")) is not None:
+                # See issue at https://github.com/py-pdf/pypdf/issues/3324
+                # Some applications violate the XMP metadata standard regarding `dc:creator` which should
+                # be an "ordered array" and thus a sequence, but use an unordered array (bag) instead.
+                # This seems to stem from the fact that the original Dublin Core specification does indeed
+                # use bags or direct values, while PDFs are expected to follow the XMP standard and ignore
+                # the plain Dublin Core variant. For this reason, add a fallback here to deal with such
+                # issues accordingly.
+                retval.extend(bags)
             else:
                 value = converter(self._get_text(element))
                 retval.append(value)
@@ -205,13 +222,14 @@ def _getter_single(
     return get
 
 
-class XmpInformation(PdfObject):
+class XmpInformation(XmpInformationProtocol, PdfObject):
     """
-    An object that represents Adobe XMP metadata.
-    Usually accessed by :py:attr:`xmp_metadata()<pypdf.PdfReader.xmp_metadata>`
+    An object that represents Extensible Metadata Platform (XMP) metadata.
+    Usually accessed by :py:attr:`xmp_metadata()<pypdf.PdfReader.xmp_metadata>`.
 
     Raises:
       PdfReadError: if XML is invalid
+
     """
 
     def __init__(self, stream: ContentStream) -> None:
@@ -219,33 +237,21 @@ class XmpInformation(PdfObject):
         try:
             data = self.stream.get_data()
             doc_root: Document = parseString(data)  # noqa: S318
-        except ExpatError as e:
+        except (AttributeError, ExpatError) as e:
             raise PdfReadError(f"XML in XmpInformation was invalid: {e}")
         self.rdf_root: XmlElement = doc_root.getElementsByTagNameNS(
             RDF_NAMESPACE, "RDF"
         )[0]
         self.cache: Dict[Any, Any] = {}
 
-    @property
-    def rdfRoot(self) -> XmlElement:  # deprecated
-        deprecate_with_replacement("rdfRoot", "rdf_root", "4.0.0")
-        return self.rdf_root
-
     def write_to_stream(
         self, stream: StreamType, encryption_key: Union[None, str, bytes] = None
     ) -> None:
-        self.stream.write_to_stream(stream, encryption_key)
-
-    def writeToStream(
-        self, stream: StreamType, encryption_key: Union[None, str, bytes]
-    ) -> None:  # deprecated
-        """
-        Use :meth:`write_to_stream` instead.
-
-        .. deprecated:: 1.28.0
-        """
-        deprecation_with_replacement("writeToStream", "write_to_stream", "3.0.0")
-        self.write_to_stream(stream, encryption_key)
+        if encryption_key is not None:  # deprecated
+            deprecate_no_replacement(
+                "the encryption_key parameter of write_to_stream", "5.0.0"
+            )
+        self.stream.write_to_stream(stream)
 
     def get_element(self, about_uri: str, namespace: str, name: str) -> Iterator[Any]:
         for desc in self.rdf_root.getElementsByTagNameNS(RDF_NAMESPACE, "Description"):
@@ -255,41 +261,17 @@ class XmpInformation(PdfObject):
                     yield attr
                 yield from desc.getElementsByTagNameNS(namespace, name)
 
-    def getElement(
-        self, aboutUri: str, namespace: str, name: str
-    ) -> Iterator[Any]:  # deprecated
-        """
-        Use :meth:`get_element` instead.
-
-        .. deprecated:: 1.28.0
-        """
-        deprecation_with_replacement("getElement", "get_element", "3.0.0")
-        return self.get_element(aboutUri, namespace, name)
-
     def get_nodes_in_namespace(self, about_uri: str, namespace: str) -> Iterator[Any]:
         for desc in self.rdf_root.getElementsByTagNameNS(RDF_NAMESPACE, "Description"):
             if desc.getAttributeNS(RDF_NAMESPACE, "about") == about_uri:
                 for i in range(desc.attributes.length):
                     attr = desc.attributes.item(i)
-                    if attr.namespaceURI == namespace:
+                    if attr and attr.namespaceURI == namespace:
                         yield attr
                 for child in desc.childNodes:
                     if child.namespaceURI == namespace:
                         yield child
 
-    def getNodesInNamespace(
-        self, aboutUri: str, namespace: str
-    ) -> Iterator[Any]:  # deprecated
-        """
-        Use :meth:`get_nodes_in_namespace` instead.
-
-        .. deprecated:: 1.28.0
-        """
-        deprecation_with_replacement(
-            "getNodesInNamespace", "get_nodes_in_namespace", "3.0.0"
-        )
-        return self.get_nodes_in_namespace(aboutUri, namespace)
-
     def _get_text(self, element: XmlElement) -> str:
         text = ""
         for child in element.childNodes:
@@ -347,7 +329,7 @@ class XmpInformation(PdfObject):
     """Unique identifier of the work from which this resource was derived."""
 
     dc_subject = property(_getter_bag(DC_NAMESPACE, "subject"))
-    """An unordered array of descriptive phrases or keywrods that specify the
+    """An unordered array of descriptive phrases or keywords that specify the
     topic of the content of the resource."""
 
     dc_title = property(_getter_langalt(DC_NAMESPACE, "title"))
@@ -360,10 +342,10 @@ class XmpInformation(PdfObject):
     """An unformatted text string representing document keywords."""
 
     pdf_pdfversion = property(_getter_single(PDF_NAMESPACE, "PDFVersion"))
-    """The PDF file version, for example 1.0, 1.3."""
+    """The PDF file version, for example 1.0 or 1.3."""
 
     pdf_producer = property(_getter_single(PDF_NAMESPACE, "Producer"))
-    """The name of the tool that created the PDF document."""
+    """The name of the tool that saved the document as a PDF."""
 
     xmp_create_date = property(
         _getter_single(XMP_NAMESPACE, "CreateDate", _converter_date)
@@ -374,16 +356,6 @@ class XmpInformation(PdfObject):
     The date and time are returned as a UTC datetime.datetime object.
     """
 
-    @property
-    def xmp_createDate(self) -> datetime.datetime:  # deprecated
-        deprecate_with_replacement("xmp_createDate", "xmp_create_date", "4.0.0")
-        return self.xmp_create_date
-
-    @xmp_createDate.setter
-    def xmp_createDate(self, value: datetime.datetime) -> None:  # deprecated
-        deprecate_with_replacement("xmp_createDate", "xmp_create_date", "4.0.0")
-        self.xmp_create_date = value
-
     xmp_modify_date = property(
         _getter_single(XMP_NAMESPACE, "ModifyDate", _converter_date)
     )
@@ -393,16 +365,6 @@ class XmpInformation(PdfObject):
     The date and time are returned as a UTC datetime.datetime object.
     """
 
-    @property
-    def xmp_modifyDate(self) -> datetime.datetime:  # deprecated
-        deprecate_with_replacement("xmp_modifyDate", "xmp_modify_date", "4.0.0")
-        return self.xmp_modify_date
-
-    @xmp_modifyDate.setter
-    def xmp_modifyDate(self, value: datetime.datetime) -> None:  # deprecated
-        deprecate_with_replacement("xmp_modifyDate", "xmp_modify_date", "4.0.0")
-        self.xmp_modify_date = value
-
     xmp_metadata_date = property(
         _getter_single(XMP_NAMESPACE, "MetadataDate", _converter_date)
     )
@@ -412,55 +374,21 @@ class XmpInformation(PdfObject):
     The date and time are returned as a UTC datetime.datetime object.
     """
 
-    @property
-    def xmp_metadataDate(self) -> datetime.datetime:  # deprecated
-        deprecate_with_replacement("xmp_metadataDate", "xmp_metadata_date", "4.0.0")
-        return self.xmp_metadata_date
-
-    @xmp_metadataDate.setter
-    def xmp_metadataDate(self, value: datetime.datetime) -> None:  # deprecated
-        deprecate_with_replacement("xmp_metadataDate", "xmp_metadata_date", "4.0.0")
-        self.xmp_metadata_date = value
-
     xmp_creator_tool = property(_getter_single(XMP_NAMESPACE, "CreatorTool"))
     """The name of the first known tool used to create the resource."""
 
-    @property
-    def xmp_creatorTool(self) -> str:  # deprecated
-        deprecation_with_replacement("xmp_creatorTool", "xmp_creator_tool", "3.0.0")
-        return self.xmp_creator_tool
-
-    @xmp_creatorTool.setter
-    def xmp_creatorTool(self, value: str) -> None:  # deprecated
-        deprecation_with_replacement("xmp_creatorTool", "xmp_creator_tool", "3.0.0")
-        self.xmp_creator_tool = value
-
     xmpmm_document_id = property(_getter_single(XMPMM_NAMESPACE, "DocumentID"))
     """The common identifier for all versions and renditions of this resource."""
 
-    @property
-    def xmpmm_documentId(self) -> str:  # deprecated
-        deprecation_with_replacement("xmpmm_documentId", "xmpmm_document_id", "3.0.0")
-        return self.xmpmm_document_id
-
-    @xmpmm_documentId.setter
-    def xmpmm_documentId(self, value: str) -> None:  # deprecated
-        deprecation_with_replacement("xmpmm_documentId", "xmpmm_document_id", "3.0.0")
-        self.xmpmm_document_id = value
-
     xmpmm_instance_id = property(_getter_single(XMPMM_NAMESPACE, "InstanceID"))
     """An identifier for a specific incarnation of a document, updated each
     time a file is saved."""
 
-    @property
-    def xmpmm_instanceId(self) -> str:  # deprecated
-        deprecation_with_replacement("xmpmm_instanceId", "xmpmm_instance_id", "3.0.0")
-        return cast(str, self.xmpmm_instance_id)
+    pdfaid_part = property(_getter_single(PDFAID_NAMESPACE, "part"))
+    """The part of the PDF/A standard that the document conforms to (e.g., 1, 2, 3)."""
 
-    @xmpmm_instanceId.setter
-    def xmpmm_instanceId(self, value: str) -> None:  # deprecated
-        deprecation_with_replacement("xmpmm_instanceId", "xmpmm_instance_id", "3.0.0")
-        self.xmpmm_instance_id = value
+    pdfaid_conformance = property(_getter_single(PDFAID_NAMESPACE, "conformance"))
+    """The conformance level within the PDF/A standard (e.g., 'A', 'B', 'U')."""
 
     @property
     def custom_properties(self) -> Dict[Any, Any]:
@@ -470,6 +398,7 @@ class XmpInformation(PdfObject):
 
         Returns:
             A dictionary of key/value items for custom metadata properties.
+
         """
         if not hasattr(self, "_custom_properties"):
             self._custom_properties = {}
